
TODO: TODO_40_10_18_32: add custom base to all schemas

Some of the `*Schema` classes are already re-based from `Schema` to `ObjectSchema`
to re-use `@post_load` `make_object`.

Those `*Schema` classes which did NOT use `@post_load` are still using base `Schema`.
Consider re-basing them to `ObjectSchema` or something else and reuse common boilerplates.

